summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorDaniel Burrows <dburrows@debian.org>2010-05-01 08:32:29 -0700
committerDaniel Burrows <dburrows@debian.org>2010-05-01 08:32:29 -0700
commit5e3e8c09991a8c784f0b88ab9eab655464354dae (patch)
treefd0fab0758aefe6dc8c48398928a1fa8aa9da019 /src
parent7553d1569f96d57da01c782970b4910a811810bb (diff)
downloadaptitude-5e3e8c09991a8c784f0b88ab9eab655464354dae.tar.gz
Fix some places where comments in the generic dynamic list referred to
tabs and areas.
Diffstat (limited to 'src')
-rw-r--r--src/generic/util/dynamic_list.h19
1 files changed, 12 insertions, 7 deletions
diff --git a/src/generic/util/dynamic_list.h b/src/generic/util/dynamic_list.h
index fb3698e4..ec79723d 100644
--- a/src/generic/util/dynamic_list.h
+++ b/src/generic/util/dynamic_list.h
@@ -33,11 +33,12 @@ namespace aptitude
public:
virtual ~dynamic_list();
- /** \brief Enumerate the tabs in this area.
+ /** \brief Enumerate the values in this list.
*
* To get a consistent picture of the tabs, the caller should
* enumerate them before any other process adds or removes a tab.
* Typically this means enumerating them in a tight loop.
*
* The returned enumerator will be valid indefinitely. In
* order to provide this guarantee, it may hold a strong
@@ -69,10 +70,14 @@ namespace aptitude
class writable_dynamic_list : public dynamic_list<T>
{
/** \brief Append a value to this list. */
- virtual void append(const T &tab) = 0;
+ virtual void append(const T &value) = 0;
- /** \brief Remove a value from this list. */
- virtual void remove(const T &tab) = 0;
+ /** \brief Remove a value from this list.
+ *
+ * An arbitrary matching element is removed if there are
+ * duplicates.
+ */
+ virtual void remove(const T &value) = 0;
};
template<typename T>
@@ -33,11 +33,12 @@ namespace aptitude
*
- * To get a consistent picture of the tabs, the caller should
- * enumerate them before any other process adds or removes a tab.
- * Typically this means enumerating them in a tight loop.
+ * To get a consistent picture of the values, the caller should
+ * enumerate them before any other process adds or removes a
+ * value. Typically this means enumerating them in a tight
+ * loop.
*
* The returned enumerator will be valid indefinitely. In